%define _prefix /scisoft
%define _bindir %{_prefix}/bin
%define module rvsao

# Since IRAF is an externally built binary, we do not bother with preparing
# debug packages for its external addon modules either.
%define debug_package %{nil}

Name:           scisoft-iraf-rvsao
Version:        2.8.2
Release:        1%{?dist}
Summary:        Radial velocity extraction tools
Distribution:   Scisoft
Group:          Applications/Scientific
License:        Distributable
URL:            http://tdc-www.harvard.edu/iraf/rvsao/
Source0:        ftp://iraf.noao.edu/iraf/extern-v216/%{module}-src.tar.gz
Source2:        ftp://iraf.noao.edu/iraf/extern-v216/%{module}-bin.linux.tar.gz

BuildRequires:  /usr/bin/tee
BuildRequires:  /usr/bin/cat
BuildRequires:  /usr/bin/grep
BuildRequires:  sudo
BuildRequires:  scisoft-common
BuildRequires:  scisoft-iraf
Requires:       scisoft-iraf
AutoReq:        no

%description
RVSAO is an IRAF add-on package developed at the Smithsonian Astrophysical
Observatory Telescope Data Center to obtain radial velocities from spectra using
cross-correlation and emission line fitting techniques.

%prep
%setup -q -n %{module}

%build
# IRAF does not provide an easy to use build procedure that will allow building
# external packages within a build directory and installing it into the
# buildroot for packaging. Therefore we are forced to rely on the user to have
# sudo rights, to prepare the files directly in /scisoft.
sudo install -m 755 -d %{_datadir}/iraf/extern
sudo cp -r %{_builddir}/%{module} %{_datadir}/iraf/extern/%{module}
%if %{_arch} == x86_64
sudo install -m 755 -d %{_datadir}/iraf/extern/%{module}/bin.linux64
sudo tar xzf %{SOURCE2} -C %{_datadir}/iraf/extern/%{module}/bin.linux64
sudo chown -R root:root %{_datadir}/iraf/extern/%{module}/bin.linux64
sudo chmod -R +r %{_datadir}/iraf/extern/%{module}/bin.linux64
%else
sudo install -m 755 -d %{_datadir}/iraf/extern/%{module}/bin.linux
sudo tar xzf %{SOURCE2} -C %{_datadir}/iraf/extern/%{module}/bin.linux
sudo chown -R root:root %{_datadir}/iraf/extern/%{module}/bin.linux
sudo chmod -R +r %{_datadir}/iraf/extern/%{module}/bin.linux
%endif
cat <<EOF | sudo /bin/sh 2>&1 | tee %{_builddir}/iraf_pkg_build.log
export PATH="%{_bindir}:$PATH"
export iraf=%{_datadir}/iraf/iraf/
%if %{_arch} == x86_64
export IRAFARCH=linux64
%else
export IRAFARCH=linux
%endif
%{_bindir}/iraf_pkg.sh --source %{module}
EOF
# Check for errors from mkpkg to avoid silent build failures.
# iraf_pkg.sh always returns zero, since the IRAF cl command does not appear to
# have a sane mechanism to capture error status.
if grep 'returned error' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep '[[:alpha:]]*cc: error:' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep 'No such file or directory' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep 'error while loading' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep 'error during checkin' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi

%install
install -m 755 -d %{buildroot}%{_datadir}/iraf/extern
cp -r %{_datadir}/iraf/extern/%{module} %{buildroot}%{_datadir}/iraf/extern/%{module}
install -m 755 -d %{buildroot}%{_docdir}/%{module}
install -m 644 %{_builddir}/%{module}/Readme %{buildroot}%{_docdir}/%{module}/
install -m 644 %{_builddir}/%{module}/NEWS %{buildroot}%{_docdir}/%{module}/

%clean
# Cleaning up since an inplace build was performed with sudo.
sudo %{_bindir}/iraf_pkg.sh --remove %{module}
sudo rm -rf %{_datadir}/iraf/extern/%{module}
sudo rmdir --ignore-fail-on-non-empty %{_datadir}/iraf/extern

%files
%docdir %{_docdir}/%{module}
%{_prefix}
%defattr(-,root,root,-)

# Edit the extern.pkg file the first time and remove it the last time.

%post
# argument=1 -> this is the first time it is installed (no updates)
if [ "$*" = 1 ]; then
  %{_bindir}/iraf_pkg.sh --edit %{module} >/dev/null 2>&1
fi

%postun
# argument=0 -> this is the last time it is de-installed (no updates)
if [ "$*" = 0 ]; then
  %{_bindir}/iraf_pkg.sh --remove %{module} >/dev/null 2>&1
fi

%changelog
* Mon Mar 5 2018 Artur Szostak <aszostak@partner.eso.org>
- Integrating module into automated build system for Scisoft.

* Fri Oct 18 2013 Carlos Guirao
- Integration for scisoft 8
